@@ -23,20 +23,52 @@
  */
 package net.sf.jasperreports.engine;
 
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
+
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRCommonImage.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRCommonImage.java 3583 2010-03-12 11:35:40Z shertage $
  */
 public interface JRCommonImage extends JRCommonGraphicElement, JRBoxContainer
 {
 
 	/**
-	 * Gets the image scale type.
-	 * @return one of the scale constants in this class
+	 * @deprecated Replaced by {@link #getScaleImageValue()}.
 	 */
 	public byte getScaleImage();
-
+	
+	/**
+	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
+	 */
 	public Byte getOwnScaleImage();
+	
+	/**
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
+	 */
+	public void setScaleImage(byte scaleImage);
+		
+	/**
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
+	 */
+	public void setScaleImage(Byte scaleImage);
+
+	/**
+	 * Gets the image scale type.
+	 * @return a value representing one of the scale type constants in {@link ScaleImageEnum}
+	 */
+	public ScaleImageEnum getScaleImageValue();
+	
+	/**
+	 * Gets the image own scale type.
+	 * @return a value representing one of the scale type constants in {@link ScaleImageEnum}
+	 */
+	public ScaleImageEnum getOwnScaleImageValue();
+	
+	/**
+	 * Sets the image scale type.
+	 * @param scaleImageEnum a value representing one of the scale type constants in {@link ScaleImageEnum}
+	 */
+	public void setScaleImage(ScaleImageEnum scaleImageEnum);
 
 }
