@@ -23,24 +23,37 @@
  */
 package net.sf.jasperreports.engine;
 
+import net.sf.jasperreports.engine.type.LineDirectionEnum;
+
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPrintLine.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRPrintLine.java 3583 2010-03-12 11:35:40Z shertage $
  */
 public interface JRPrintLine extends JRPrintGraphicElement
 {
 
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getDirectionValue()}.
 	 */
 	public byte getDirection();
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setDirection(LineDirectionEnum)}.
 	 */
 	public void setDirection(byte direction);
 
+	/**
+	 * Gets the line direction.
+	 * @return a value representing one of the line direction constants in {@link LineDirectionEnum}
+	 */
+	public LineDirectionEnum getDirectionValue();
+	
+	/**
+	 * Sets the line direction.
+	 * @param lineDirectionEnum a value representing one of the line direction constants in {@link LineDirectionEnum}
+	 */
+	public void setDirection(LineDirectionEnum lineDirectionEnum);
 
 }
