@@ -28,18 +28,8 @@ package net.sf.jasperreports.engine;
  * An abstract representation of a graphic element representing a rectangle.
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRRectangle.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRRectangle.java 3407 2010-02-12 15:40:56Z teodord $
  */
 public interface JRRectangle extends JRGraphicElement, JRCommonRectangle
 {
-
-	
-	/**
-	 * Sets the corner radius for rectangles with round corners.
-	 */
-	public void setRadius(int radius);
-
-	public void setRadius(Integer radius);
-
-	
 }
