@@ -50,6 +50,7 @@ import net.sf.jasperreports.charts.JRTimeSeriesPlot;
 import net.sf.jasperreports.charts.JRValueDataset;
 import net.sf.jasperreports.charts.JRXyDataset;
 import net.sf.jasperreports.charts.JRXyzDataset;
+import net.sf.jasperreports.charts.type.EdgeEnum;
 import net.sf.jasperreports.engine.JRAnchor;
 import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRChart;
@@ -60,12 +61,15 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.JRGroup;
-import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRHyperlinkHelper;
 import net.sf.jasperreports.engine.JRHyperlinkParameter;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRVisitor;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -74,7 +78,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseChart.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRBaseChart.java 3715 2010-04-08 18:08:49Z teodord $
  */
 public class JRBaseChart extends JRBaseElement implements JRChart
 {
@@ -116,7 +120,7 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	 *
 	 */
 	protected Boolean showLegend = null;
-	protected byte evaluationTime = JRExpression.EVALUATION_TIME_NOW;
+	protected EvaluationTimeEnum evaluationTimeValue = EvaluationTimeEnum.NOW;
 	protected String linkType;
 	protected String linkTarget;
 	private JRHyperlinkParameter[] hyperlinkParameters;
@@ -125,8 +129,8 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	protected Color subtitleColor = null;
 	protected Color legendColor = null;
 	protected Color legendBackgroundColor = null;
-	protected Byte legendPositionByte = null;
-	protected Byte titlePositionByte = null;
+	protected EdgeEnum legendPositionValue = null;
+	protected EdgeEnum titlePositionValue = null;
 
 	protected String renderType;
 	protected String theme;
@@ -273,15 +277,15 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 		}
 
 		showLegend = chart.getShowLegend();
-		evaluationTime = chart.getEvaluationTime();
+		evaluationTimeValue = chart.getEvaluationTimeValue();
 		linkType = chart.getLinkType();
 		linkTarget = chart.getLinkTarget();
-		titlePositionByte = chart.getTitlePositionByte();
+		titlePositionValue = chart.getTitlePositionValue();
 		titleColor = chart.getOwnTitleColor();
 		subtitleColor = chart.getOwnSubtitleColor();
 		legendColor = chart.getOwnLegendColor();
 		legendBackgroundColor = chart.getOwnLegendBackgroundColor();
-		legendPositionByte = chart.getLegendPositionByte();
+		legendPositionValue = chart.getLegendPositionValue();
 		renderType = chart.getRenderType();
 		theme = chart.getTheme();
 		
@@ -341,11 +345,19 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
 	 */
 	public byte getEvaluationTime()
 	{
-		return evaluationTime;
+		return getEvaluationTimeValue().getValue();
+	}
+		
+	/**
+	 *
+	 */
+	public EvaluationTimeEnum getEvaluationTimeValue()
+	{
+		return evaluationTimeValue;
 	}
 		
 	/**
@@ -381,37 +393,53 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #getTitlePositionByte()}
+	 * @deprecated Replaced by {@link #getTitlePositionValue()}
 	 */
 	public byte getTitlePosition()
 	{
-		return titlePositionByte == null ? JRChart.EDGE_TOP : titlePositionByte.byteValue();
+		return getTitlePositionValue() == null ? EdgeEnum.TOP.getValue() : getTitlePositionValue().getValue();
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #setTitlePosition(Byte)}
+	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
 	 */
 	public void setTitlePosition(byte titlePosition)
 	{
-		setTitlePosition(new Byte(titlePosition));
+		setTitlePosition(EdgeEnum.getByValue(titlePosition));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getTitlePositionValue()}
 	 */
 	public Byte getTitlePositionByte()
 	{
-		return titlePositionByte;
+		return getTitlePositionValue() == null ? null : getTitlePositionValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
+	 */
+	public void setTitlePosition(Byte titlePosition)
+	{
+		setTitlePosition(EdgeEnum.getByValue(titlePosition));
 	}
 
 	/**
 	 *
 	 */
-	public void setTitlePosition(Byte titlePosition)
+	public EdgeEnum getTitlePositionValue()
 	{
-		Byte old = this.titlePositionByte;
-		this.titlePositionByte = titlePosition;
-		getEventSupport().firePropertyChange(PROPERTY_TITLE_POSITION, old, this.titlePositionByte);
+		return titlePositionValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setTitlePosition(EdgeEnum titlePositionValue)
+	{
+		EdgeEnum old = this.titlePositionValue;
+		this.titlePositionValue = titlePositionValue;
+		getEventSupport().firePropertyChange(PROPERTY_TITLE_POSITION, old, this.titlePositionValue);
 	}
 
 	/**
@@ -510,45 +538,69 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	}
 	
 	/**
-	 * @deprecated Replaced by {@link #getLegendPositionByte()}
+	 * @deprecated Replaced by {@link #getLegendPositionValue()}
 	 */
 	public byte getLegendPosition()
 	{
-		return legendPositionByte == null? JRChart.EDGE_BOTTOM : legendPositionByte.byteValue();
+		return getLegendPositionValue() == null? EdgeEnum.BOTTOM.getValue() : getLegendPositionValue().getValue();
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(Byte)}
+	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
 	 */
 	public void setLegendPosition(byte legendPosition)
 	{
-		setLegendPosition(new Byte(legendPosition));
+		setLegendPosition(EdgeEnum.getByValue(legendPosition));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getLegendPositionValue()}
 	 */
 	public Byte getLegendPositionByte()
 	{
-		return legendPositionByte;
+		return getLegendPositionValue() == null? null : getLegendPositionValue().getValueByte();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
 	 */
 	public void setLegendPosition(Byte legendPosition)
 	{
-		Byte old = this.legendPositionByte;
-		this.legendPositionByte = legendPosition;
-		getEventSupport().firePropertyChange(PROPERTY_LEGEND_POSITION, old, this.legendPositionByte);
+		setLegendPosition(EdgeEnum.getByValue(legendPosition));
 	}
 
 	/**
 	 *
 	 */
+	public EdgeEnum getLegendPositionValue()
+	{
+		return legendPositionValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setLegendPosition(EdgeEnum legendPositionValue)
+	{
+		EdgeEnum old = this.legendPositionValue;
+		this.legendPositionValue = legendPositionValue;
+		getEventSupport().firePropertyChange(PROPERTY_LEGEND_POSITION, old, this.legendPositionValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
+	 */
 	public byte getHyperlinkType()
 	{
-		return JRHyperlinkHelper.getHyperlinkType(this);
+		return getHyperlinkTypeValue().getValue();
+	}
+		
+	/**
+	 *
+	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return JRHyperlinkHelper.getHyperlinkTypeValue(this);
 	}
 		
 	/**
@@ -693,9 +745,9 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
@@ -1156,25 +1208,6 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	}
 	
 	
-	protected void normalizeLinkType()
-	{
-		if (linkType == null)
-		{
-			 linkType = JRHyperlinkHelper.getLinkType(hyperlinkType);
-		}
-		hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	}
-
-	protected void normalizeLinkTarget()
-	{
-		if (linkTarget == null)
-		{
-			 linkTarget = JRHyperlinkHelper.getLinkTarget(hyperlinkTarget);
-		}
-		hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
-	}
-
-	
 	public JRExpression getHyperlinkTooltipExpression()
 	{
 		return hyperlinkTooltipExpression;
@@ -1196,7 +1229,7 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	{
 		JRBaseChart clone = (JRBaseChart)super.clone();
 		
-		clone.lineBox = (JRLineBox)lineBox.clone(clone);
+		clone.lineBox = lineBox.clone(clone);
 
 		if (hyperlinkParameters != null)
 		{
@@ -1249,30 +1282,102 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 	}
 
 
-	/**
+	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
-	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID_3_1_3;
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
 	private Byte border = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte topBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte leftBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte bottomBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte rightBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Color borderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color topBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color leftBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color bottomBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color rightBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer padding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer topPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer leftPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer bottomPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer rightPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private boolean isShowLegend = false;
-	private byte legendPosition = JRChart.EDGE_BOTTOM;
-	private byte titlePosition = JRChart.EDGE_TOP;
-	private byte hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	private byte hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
+	/**
+	 * @deprecated
+	 */
+	private byte legendPosition;
+	/**
+	 * @deprecated
+	 */
+	private byte titlePosition;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkType;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkTarget;
+	/**
+	 * @deprecated
+	 */
+	private byte evaluationTime;
+	/**
+	 * @deprecated
+	 */
+	private Byte legendPositionByte = null;
+	/**
+	 * @deprecated
+	 */
+	private Byte titlePositionByte = null;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
@@ -1316,14 +1421,35 @@ public class JRBaseChart extends JRBaseElement implements JRChart
 			rightPadding = null;
 		}
 
-		normalizeLinkType();
-		normalizeLinkTarget();
-		
-		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_1_3)
+		if (linkType == null)
 		{
-			showLegend = Boolean.valueOf(isShowLegend);
-			legendPositionByte = new Byte(legendPosition);
-			titlePositionByte = new Byte(titlePosition);
+			 linkType = JRHyperlinkHelper.getLinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
+		}
+
+		if (linkTarget == null)
+		{
+			 linkTarget = JRHyperlinkHelper.getLinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+		}
+		
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			evaluationTimeValue = EvaluationTimeEnum.getByValue(evaluationTime);
+			
+			if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_1_3)
+			{
+				legendPositionValue = EdgeEnum.getByValue(legendPosition);
+				titlePositionValue = EdgeEnum.getByValue(titlePosition);
+				showLegend = Boolean.valueOf(isShowLegend);
+			}
+			else
+			{
+				legendPositionValue = EdgeEnum.getByValue(legendPositionByte);
+				titlePositionValue = EdgeEnum.getByValue(titlePositionByte);
+				
+				legendPositionByte = null;
+				titlePositionByte = null;
+			}
+			
 		}
 	}
 	
