@@ -33,13 +33,20 @@ import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRGroup;
-import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRHyperlinkHelper;
 import net.sf.jasperreports.engine.JRHyperlinkParameter;
 import net.sf.jasperreports.engine.JRImage;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRVisitor;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.OnErrorTypeEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -49,7 +56,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
 /**
  * The actual implementation of a graphic element representing an image.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseImage.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRBaseImage.java 3833 2010-05-27 14:16:59Z teodord $
  */
 public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 {
@@ -74,13 +81,13 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 	/**
 	 *
 	 */
-	protected Byte scaleImage;
-	protected Byte horizontalAlignment;
-	protected Byte verticalAlignment;
+	protected ScaleImageEnum scaleImageValue;
+	protected HorizontalAlignEnum horizontalAlignmentValue;
+	protected VerticalAlignEnum verticalAlignmentValue;
 	protected Boolean isUsingCache = null;
 	protected boolean isLazy = false;
-	protected byte onErrorType = ON_ERROR_TYPE_ERROR;
-	protected byte evaluationTime = JRExpression.EVALUATION_TIME_NOW;
+	protected OnErrorTypeEnum onErrorTypeValue = OnErrorTypeEnum.ERROR;
+	protected EvaluationTimeEnum evaluationTimeValue = EvaluationTimeEnum.NOW;
 	protected String linkType;
 	protected String linkTarget;
 	private JRHyperlinkParameter[] hyperlinkParameters;
@@ -128,13 +135,13 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 	{
 		super(image, factory);
 		
-		scaleImage = image.getOwnScaleImage();
-		horizontalAlignment = image.getOwnHorizontalAlignment();
-		verticalAlignment = image.getOwnVerticalAlignment();
+		scaleImageValue = image.getOwnScaleImageValue();
+		horizontalAlignmentValue = image.getOwnHorizontalAlignmentValue();
+		verticalAlignmentValue = image.getOwnVerticalAlignmentValue();
 		isUsingCache = image.isOwnUsingCache();
 		isLazy = image.isLazy();
-		onErrorType = image.getOnErrorType();
-		evaluationTime = image.getEvaluationTime();
+		onErrorTypeValue = image.getOnErrorTypeValue();
+		evaluationTimeValue = image.getEvaluationTimeValue();
 		linkType = image.getLinkType();
 		linkTarget = image.getLinkTarget();
 		hyperlinkParameters = JRBaseHyperlink.copyHyperlinkParameters(image, factory);
@@ -155,102 +162,178 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getScaleImageValue()}.
 	 */
 	public byte getScaleImage()
 	{
-		return JRStyleResolver.getScaleImage(this);
-	}
-
-	public Byte getOwnScaleImage()
-	{
-		return scaleImage;
+		return getScaleImageValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
+	 */
+	public Byte getOwnScaleImage()
+	{
+		return getOwnScaleImageValue() == null ? null : getOwnScaleImageValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
 	 */
 	public void setScaleImage(byte scaleImage)
 	{
-		setScaleImage(new Byte(scaleImage));
+		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
 	 */
 	public void setScaleImage(Byte scaleImage)
 	{
-		Object old = this.scaleImage;
-		this.scaleImage = scaleImage;
-		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_SCALE_IMAGE, old, this.scaleImage);
+		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
 	}
 
 	/**
-	 *
+	 * 
+	 */
+	public ScaleImageEnum getScaleImageValue()
+	{
+		return JRStyleResolver.getScaleImageValue(this);
+	}
+
+	/**
+	 * 
+	 */
+	public ScaleImageEnum getOwnScaleImageValue()
+	{
+		return this.scaleImageValue;
+	}
+
+	/**
+	 * 
+	 */
+	public void setScaleImage(ScaleImageEnum scaleImageValue)
+	{
+		Object old = this.scaleImageValue;
+		this.scaleImageValue = scaleImageValue;
+		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_SCALE_IMAGE, old, this.scaleImageValue);
+	}
+
+
+	/**
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignmentValue().getValue();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
+	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return horizontalAlignment;
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return JRStyleResolver.getHorizontalAlignmentValue(this);
+	}
+
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return horizontalAlignmentValue;
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
-		setHorizontalAlignment(new Byte(horizontalAlignment));
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
-		Object old = this.horizontalAlignment;
-		this.horizontalAlignment = horizontalAlignment;
-		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_HORIZONTAL_ALIGNMENT, old, this.horizontalAlignment);
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 		
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignmentValue)
+	{
+		Object old = this.horizontalAlignmentValue;
+		this.horizontalAlignmentValue = horizontalAlignmentValue;
+		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_HORIZONTAL_ALIGNMENT, old, this.horizontalAlignmentValue);
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public byte getVerticalAlignment()
 	{
-		return JRStyleResolver.getVerticalAlignment(this);
+		return getVerticalAlignmentValue().getValue();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
+	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return verticalAlignment;
+		return getOwnVerticalAlignmentValue() == null ? null : getVerticalAlignmentValue().getValueByte();
 	}
 
 	/**
 	 *
 	 */
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return JRStyleResolver.getVerticalAlignmentValue(this);
+	}
+
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return verticalAlignmentValue;
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
-		setVerticalAlignment(new Byte(verticalAlignment));
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
+	public void setVerticalAlignment(Byte verticalAlignment)
+	{
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
 	}
 		
 	/**
 	 *
 	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignmentValue)
 	{
-		Object old = this.verticalAlignment;
-		this.verticalAlignment = verticalAlignment;
-		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_VERTICAL_ALIGNMENT, old, this.verticalAlignment);
+		Object old = this.verticalAlignmentValue;
+		this.verticalAlignmentValue = verticalAlignmentValue;
+		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_VERTICAL_ALIGNMENT, old, this.verticalAlignmentValue);
 	}
 		
 	/**
@@ -314,29 +397,53 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOnErrorTypeValue()}
 	 */
 	public byte getOnErrorType()
 	{
-		return onErrorType;
+		return getOnErrorTypeValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setOnErrorType(OnErrorTypeEnum)}
 	 */
 	public void setOnErrorType(byte onErrorType)
 	{
-		byte old = this.onErrorType;
-		this.onErrorType = onErrorType;
-		getEventSupport().firePropertyChange(PROPERTY_ON_ERROR_TYPE, old, this.onErrorType);
+		setOnErrorType(OnErrorTypeEnum.getByValue(onErrorType));
 	}
 
 	/**
-	 *
+	 * 
+	 */
+	public OnErrorTypeEnum getOnErrorTypeValue()
+	{
+		return this.onErrorTypeValue;
+	}
+
+	/**
+	 * 
+	 */
+	public void setOnErrorType(OnErrorTypeEnum onErrorTypeValue)
+	{
+		OnErrorTypeEnum old = this.onErrorTypeValue;
+		this.onErrorTypeValue = onErrorTypeValue;
+		getEventSupport().firePropertyChange(PROPERTY_ON_ERROR_TYPE, old, this.onErrorTypeValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
 	 */
 	public byte getEvaluationTime()
 	{
-		return evaluationTime;
+		return getEvaluationTimeValue().getValue();
+	}
+		
+	/**
+	 *
+	 */
+	public EvaluationTimeEnum getEvaluationTimeValue()
+	{
+		return evaluationTimeValue;
 	}
 		
 	/**
@@ -356,11 +463,19 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
 	 */
 	public byte getHyperlinkType()
 	{
-		return JRHyperlinkHelper.getHyperlinkType(this);
+		return getHyperlinkTypeValue().getValue();
+	}
+		
+	/**
+	 *
+	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return JRHyperlinkHelper.getHyperlinkTypeValue(this);
 	}
 		
 	/**
@@ -909,24 +1024,6 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 	}
 	
 	
-	protected void normalizeLinkType()
-	{
-		if (linkType == null)
-		{
-			 linkType = JRHyperlinkHelper.getLinkType(hyperlinkType);
-		}
-		hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	}
-
-	protected void normalizeLinkTarget()
-	{
-		if (linkTarget == null)
-		{
-			 linkTarget = JRHyperlinkHelper.getLinkTarget(hyperlinkTarget);
-		}
-		hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
-	}
-
 	public JRExpression getHyperlinkTooltipExpression()
 	{
 		return hyperlinkTooltipExpression;
@@ -940,7 +1037,7 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 	{
 		JRBaseImage clone = (JRBaseImage)super.clone();
 		
-		clone.lineBox = (JRLineBox)lineBox.clone(clone);
+		clone.lineBox = lineBox.clone(clone);
 
 		if (hyperlinkParameters != null)
 		{
@@ -980,31 +1077,116 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 	}
 
 
-	/**
+	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
+	private Byte horizontalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte verticalAlignment;
+	/**
+	 * @deprecated
+	 */
 	private Byte border = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte topBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte leftBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte bottomBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte rightBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Color borderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color topBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color leftBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color bottomBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color rightBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer padding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer topPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer leftPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer bottomPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer rightPadding = null;
-	private byte hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	private byte hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkType;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkTarget;
+	/**
+	 * @deprecated
+	 */
+	private Byte scaleImage;
+	/**
+	 * @deprecated
+	 */
+	private byte onErrorType;
+	/**
+	 * @deprecated
+	 */
+	private byte evaluationTime;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
 		in.defaultReadObject();
 
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			horizontalAlignmentValue = HorizontalAlignEnum.getByValue(horizontalAlignment);
+			verticalAlignmentValue = VerticalAlignEnum.getByValue(verticalAlignment);
+			scaleImageValue = ScaleImageEnum.getByValue(scaleImage);
+			onErrorTypeValue = OnErrorTypeEnum.getByValue(onErrorType);
+			evaluationTimeValue = EvaluationTimeEnum.getByValue(evaluationTime);
+
+			horizontalAlignment = null;
+			verticalAlignment = null;
+			scaleImage = null;
+		}
+		
 		if (lineBox == null)
 		{
 			lineBox = new JRBaseLineBox(this);
@@ -1043,7 +1225,14 @@ public class JRBaseImage extends JRBaseGraphicElement implements JRImage
 			rightPadding = null;
 		}
 
-		normalizeLinkType();
-		normalizeLinkTarget();
+		if (linkType == null)
+		{
+			 linkType = JRHyperlinkHelper.getLinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
+		}
+
+		if (linkTarget == null)
+		{
+			 linkTarget = JRHyperlinkHelper.getLinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+		}
 	}
 }
