@@ -47,12 +47,12 @@ import net.sf.jasperreports.charts.design.JRDesignPieDataset;
 import net.sf.jasperreports.charts.design.JRDesignPiePlot;
 import net.sf.jasperreports.charts.design.JRDesignScatterPlot;
 import net.sf.jasperreports.charts.design.JRDesignThermometerPlot;
-import net.sf.jasperreports.charts.design.JRDesignTimePeriodDataset;
 import net.sf.jasperreports.charts.design.JRDesignTimeSeriesDataset;
 import net.sf.jasperreports.charts.design.JRDesignTimeSeriesPlot;
 import net.sf.jasperreports.charts.design.JRDesignValueDataset;
 import net.sf.jasperreports.charts.design.JRDesignXyDataset;
 import net.sf.jasperreports.charts.design.JRDesignXyzDataset;
+import net.sf.jasperreports.charts.type.EdgeEnum;
 import net.sf.jasperreports.engine.JRAnchor;
 import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRChart;
@@ -64,7 +64,6 @@ import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.JRGroup;
-import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRHyperlinkHelper;
 import net.sf.jasperreports.engine.JRHyperlinkParameter;
 import net.sf.jasperreports.engine.JRLineBox;
@@ -73,6 +72,10 @@ import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.base.JRBaseChart;
 import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseLineBox;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -81,7 +84,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignChart.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRDesignChart.java 3715 2010-04-08 18:08:49Z teodord $
  */
 public class JRDesignChart extends JRDesignElement implements JRChart
 {
@@ -129,7 +132,7 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	 *
 	 */
 	protected Boolean showLegend = null;
-	protected byte evaluationTime = JRExpression.EVALUATION_TIME_NOW;
+	protected EvaluationTimeEnum evaluationTimeValue = EvaluationTimeEnum.NOW;
 	protected String linkType;
 	protected String linkTarget;
 	protected Color titleColor = null;
@@ -145,8 +148,8 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	protected JRFont titleFont = null;
 	protected JRFont subtitleFont = null;
 	protected JRFont legendFont = null;
-	protected Byte legendPositionByte = null;
-	protected Byte titlePositionByte = null;
+	protected EdgeEnum legendPositionValue = null;
+	protected EdgeEnum titlePositionValue = null;
 
 	protected String customizerClass;
 
@@ -268,21 +271,37 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
 	 */
 	public byte getEvaluationTime()
 	{
-		return evaluationTime;
+		return getEvaluationTimeValue().getValue();
 	}
 		
 	/**
 	 *
 	 */
+	public EvaluationTimeEnum getEvaluationTimeValue()
+	{
+		return evaluationTimeValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setEvaluationTime(EvaluationTimeEnum)}.
+	 */
 	public void setEvaluationTime(byte evaluationTime)
 	{
-		byte old = this.evaluationTime;
-		this.evaluationTime = evaluationTime;
-		getEventSupport().firePropertyChange(PROPERTY_EVALUATION_TIME, old, this.evaluationTime);
+		setEvaluationTime(EvaluationTimeEnum.getByValue(evaluationTime));
+	}
+		
+	/**
+	 *
+	 */
+	public void setEvaluationTime(EvaluationTimeEnum evaluationTimeValue)
+	{
+		Object old = this.evaluationTimeValue;
+		this.evaluationTimeValue = evaluationTimeValue;
+		getEventSupport().firePropertyChange(PROPERTY_EVALUATION_TIME, old, this.evaluationTimeValue);
 	}
 		
 	/**
@@ -346,37 +365,53 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	}
 	
 	/**
-	 * @deprecated Replaced by {@link #getLegendPositionByte()}
+	 * @deprecated Replaced by {@link #getTitlePositionValue()}
 	 */
 	public byte getTitlePosition()
 	{
-		return titlePositionByte == null ? JRChart.EDGE_TOP : titlePositionByte.byteValue();
+		return getTitlePositionValue() == null ? EdgeEnum.TOP.getValue() : getTitlePositionValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
 	 */
 	public void setTitlePosition(byte titlePosition)
 	{
-		setTitlePosition(new Byte(titlePosition));
+		setTitlePosition(EdgeEnum.getByValue(titlePosition));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getTitlePositionValue()}
 	 */
 	public Byte getTitlePositionByte()
 	{
-		return titlePositionByte;
+		return getTitlePositionValue() == null ? null : getTitlePositionValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setTitlePosition(EdgeEnum)}
+	 */
+	public void setTitlePosition(Byte titlePosition)
+	{
+		setTitlePosition(EdgeEnum.getByValue(titlePosition));
 	}
 
 	/**
 	 *
 	 */
-	public void setTitlePosition(Byte titlePosition)
+	public EdgeEnum getTitlePositionValue()
 	{
-		Byte old = this.titlePositionByte;
-		this.titlePositionByte = titlePosition;
-		getEventSupport().firePropertyChange(JRBaseChart.PROPERTY_TITLE_POSITION, old, this.titlePositionByte);
+		return titlePositionValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setTitlePosition(EdgeEnum titlePositionValue)
+	{
+		EdgeEnum old = this.titlePositionValue;
+		this.titlePositionValue = titlePositionValue;
+		getEventSupport().firePropertyChange(JRBaseChart.PROPERTY_TITLE_POSITION, old, this.titlePositionValue);
 	}
 
 	/**
@@ -520,45 +555,77 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	}
 	
 	/**
-	 * @deprecated Replaced by {@link #getLegendPositionByte()}
+	 * @deprecated Replaced by {@link #getLegendPositionValue()}
 	 */
 	public byte getLegendPosition()
 	{
-		return legendPositionByte == null ? JRChart.EDGE_BOTTOM : legendPositionByte.byteValue();
+		return getLegendPositionValue() == null? EdgeEnum.BOTTOM.getValue() : getLegendPositionValue().getValue();
 	}
 
 	/**
-	 * @deprecated Replaced by {@link #setLegendPosition(Byte)}
+	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
 	 */
 	public void setLegendPosition(byte legendPosition)
 	{
-		setLegendPosition(new Byte(legendPosition));
+		setLegendPosition(EdgeEnum.getByValue(legendPosition));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getLegendPositionValue()}
 	 */
 	public Byte getLegendPositionByte()
 	{
-		return legendPositionByte;
+		return getLegendPositionValue() == null? null : getLegendPositionValue().getValueByte();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setLegendPosition(EdgeEnum)}
 	 */
 	public void setLegendPosition(Byte legendPosition)
 	{
-		Byte old = this.legendPositionByte;
-		this.legendPositionByte = legendPosition;
-		getEventSupport().firePropertyChange(JRBaseChart.PROPERTY_LEGEND_POSITION, old, this.legendPositionByte);
+		setLegendPosition(EdgeEnum.getByValue(legendPosition));
 	}
 
 	/**
 	 *
 	 */
+	public EdgeEnum getLegendPositionValue()
+	{
+		return legendPositionValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setLegendPosition(EdgeEnum legendPositionValue)
+	{
+		EdgeEnum old = this.legendPositionValue;
+		this.legendPositionValue = legendPositionValue;
+		getEventSupport().firePropertyChange(JRBaseChart.PROPERTY_LEGEND_POSITION, old, this.legendPositionValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
+	 */
 	public byte getHyperlinkType()
 	{
-		return JRHyperlinkHelper.getHyperlinkType(this);
+		return getHyperlinkTypeValue().getValue();
+	}
+		
+	/**
+	 *
+	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return JRHyperlinkHelper.getHyperlinkTypeValue(this);
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkType(HyperlinkTypeEnum)}.
+	 */
+	public void setHyperlinkType(byte hyperlinkType)
+	{
+		setHyperlinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
 	}
 		
 	/**
@@ -567,7 +634,7 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	 * @param hyperlinkType the built-in hyperlink type
 	 * @see #getLinkType()
 	 */
-	public void setHyperlinkType(byte hyperlinkType)
+	public void setHyperlinkType(HyperlinkTypeEnum hyperlinkType)
 	{
 		setLinkType(JRHyperlinkHelper.getLinkType(hyperlinkType));
 	}
@@ -581,9 +648,17 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHyperlinkTarget(HyperlinkTargetEnum)}.
 	 */
 	public void setHyperlinkTarget(byte hyperlinkTarget)
+	{
+		setHyperlinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+	}
+		
+	/**
+	 *
+	 */
+	public void setHyperlinkTarget(HyperlinkTargetEnum hyperlinkTarget)
 	{
 		setLinkTarget(JRHyperlinkHelper.getLinkTarget(hyperlinkTarget));
 	}
@@ -822,35 +897,7 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	public void setDataset(JRChartDataset ds)
 	{
 		Object old = this.dataset;
-		switch( ds.getDatasetType() ){
-			case JRChartDataset.CATEGORY_DATASET:
-				dataset = (JRDesignCategoryDataset)ds;
-				break;
-			case JRChartDataset.HIGHLOW_DATASET:
-				dataset = (JRDesignHighLowDataset)ds;
-				break;
-			case JRChartDataset.PIE_DATASET:
-				dataset = (JRDesignPieDataset)ds;
-				break;
-			case JRChartDataset.TIMEPERIOD_DATASET:
-				dataset = (JRDesignTimePeriodDataset)ds;
-				break;
-			case JRChartDataset.TIMESERIES_DATASET:
-				dataset = (JRDesignTimeSeriesDataset)ds;
-				break;
-			case JRChartDataset.VALUE_DATASET:
-				dataset = (JRDesignValueDataset)ds;
-				break;
-			case JRChartDataset.XY_DATASET:
-				dataset = (JRDesignXyDataset)ds;
-				break;
-			case JRChartDataset.XYZ_DATASET:
-				dataset = (JRDesignXyzDataset)ds;
-				break;
-			case JRChartDataset.GANTT_DATASET:
-				dataset = (JRDesignGanttDataset)ds;
-				break;
-		}
+		dataset = ds;
 		getEventSupport().firePropertyChange(PROPERTY_DATASET, old, this.dataset);		
 	}
 
@@ -912,9 +959,9 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
@@ -1483,24 +1530,6 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	}
 	
 	
-	protected void normalizeLinkType()
-	{
-		if (linkType == null)
-		{
-			 linkType = JRHyperlinkHelper.getLinkType(hyperlinkType);
-		}
-		hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	}
-
-	protected void normalizeLinkTarget()
-	{
-		if (linkTarget == null)
-		{
-			 linkTarget = JRHyperlinkHelper.getLinkTarget(hyperlinkTarget);
-		}
-		hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
-	}
-
 	public JRExpression getHyperlinkTooltipExpression()
 	{
 		return hyperlinkTooltipExpression;
@@ -1536,7 +1565,7 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	{
 		JRDesignChart clone = (JRDesignChart)super.clone();
 		
-		clone.lineBox = (JRLineBox)lineBox.clone(clone);
+		clone.lineBox = lineBox.clone(clone);
 
 		if (hyperlinkParameters != null)
 		{
@@ -1589,30 +1618,102 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 	}
 	
 
-	/**
+	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
-	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID_3_1_3;
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
 	private Byte border = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte topBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte leftBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte bottomBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Byte rightBorder = null;
+	/**
+	 * @deprecated
+	 */
 	private Color borderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color topBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color leftBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color bottomBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Color rightBorderColor = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer padding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer topPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer leftPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer bottomPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private Integer rightPadding = null;
+	/**
+	 * @deprecated
+	 */
 	private boolean isShowLegend = false;
-	private byte titlePosition = JRChart.EDGE_TOP;
-	private byte legendPosition = JRChart.EDGE_BOTTOM;
-	private byte hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	private byte hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
+	/**
+	 * @deprecated
+	 */
+	private byte titlePosition;
+	/**
+	 * @deprecated
+	 */
+	private byte legendPosition;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkType;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkTarget;
+	/**
+	 * @deprecated
+	 */
+	private byte evaluationTime;
+	/**
+	 * @deprecated
+	 */
+	private Byte legendPositionByte = null;
+	/**
+	 * @deprecated
+	 */
+	private Byte titlePositionByte = null;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
@@ -1656,14 +1757,34 @@ public class JRDesignChart extends JRDesignElement implements JRChart
 			rightPadding = null;
 		}
 
-		normalizeLinkType();
-		normalizeLinkTarget();
-		
-		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_1_3)
+		if (linkType == null)
 		{
-			showLegend = Boolean.valueOf(isShowLegend);
-			legendPositionByte = new Byte(legendPosition);
-			titlePositionByte = new Byte(titlePosition);
+			 linkType = JRHyperlinkHelper.getLinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
+		}
+
+		if (linkTarget == null)
+		{
+			 linkTarget = JRHyperlinkHelper.getLinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+		}
+		
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			evaluationTimeValue = EvaluationTimeEnum.getByValue(evaluationTime);
+			if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_1_3)
+			{
+				legendPositionValue = EdgeEnum.getByValue(legendPosition);
+				titlePositionValue = EdgeEnum.getByValue(titlePosition);
+				showLegend = Boolean.valueOf(isShowLegend);
+			}
+			else
+			{
+				legendPositionValue = EdgeEnum.getByValue(legendPositionByte);
+				titlePositionValue = EdgeEnum.getByValue(titlePositionByte);
+				
+				legendPositionByte = null;
+				titlePositionByte = null;
+			}
+			
 		}
 	}
 }
