@@ -64,7 +64,7 @@ import org.eclipse.jdt.internal.compiler.problem.DefaultProblemFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRJdtCompiler.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRJdtCompiler.java 3420 2010-02-18 09:17:47Z teodord $
  */
 public class JRJdtCompiler extends JRAbstractJavaCompiler
 {
@@ -611,8 +611,8 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 
 	protected IProblem[] getJavaCompilationErrors(CompilationResult result) {
 		try {
-			Method getErrorsMethod = result.getClass().getMethod("getErrors", null);
-			return (IProblem[]) getErrorsMethod.invoke(result, null);
+			Method getErrorsMethod = result.getClass().getMethod("getErrors", (Class[])null);
+			return (IProblem[]) getErrorsMethod.invoke(result, (Object[])null);
 		} catch (SecurityException e) {
 			throw new JRRuntimeException("Error resolving JDT methods", e);
 		} catch (NoSuchMethodException e) {
