@@ -54,17 +54,12 @@ import java.util.Locale;
 import java.util.Map;
 
 import net.sf.jasperreports.engine.JRAbstractExporter;
-import net.sf.jasperreports.engine.JRAlignment;
 import net.sf.jasperreports.engine.JRBoxContainer;
-import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExporterParameter;
 import net.sf.jasperreports.engine.JRGenericPrintElement;
-import net.sf.jasperreports.engine.JRHyperlink;
-import net.sf.jasperreports.engine.JRImage;
 import net.sf.jasperreports.engine.JRImageMapRenderer;
 import net.sf.jasperreports.engine.JRImageRenderer;
-import net.sf.jasperreports.engine.JRLine;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRPrintElement;
@@ -83,11 +78,16 @@ import net.sf.jasperreports.engine.JRPrintRectangle;
 import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRRenderable;
 import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.JRTextElement;
 import net.sf.jasperreports.engine.JRWrappingSvgRenderer;
 import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.fonts.FontFamily;
 import net.sf.jasperreports.engine.fonts.FontInfo;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.LineDirectionEnum;
+import net.sf.jasperreports.engine.type.LineSpacingEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
 import net.sf.jasperreports.engine.util.JRColorUtil;
 import net.sf.jasperreports.engine.util.JRFontUtil;
 import net.sf.jasperreports.engine.util.JRProperties;
@@ -103,7 +103,7 @@ import org.apache.commons.logging.LogFactory;
  * Exports a JasperReports document to XHTML format.
 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRXhtmlExporter.java 3224 2009-12-07 13:20:53Z teodord $
+ * @version $Id: JRXhtmlExporter.java 3717 2010-04-09 10:01:33Z teodord $
  */
 public class JRXhtmlExporter extends JRAbstractExporter
 {
@@ -122,6 +122,8 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	 */
 	protected static final String JR_PAGE_ANCHOR_PREFIX = "JR_PAGE_ANCHOR_";
 
+	protected static final float DEFAULT_ZOOM = 1f;
+
 	/**
 	 *
 	 */
@@ -176,6 +178,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	protected boolean isWhitePageBackground;
 	protected String encoding;
 	protected String sizeUnit = null;
+	protected float zoom = DEFAULT_ZOOM;
 	protected boolean isWrapBreakWord;
 	protected boolean isIgnorePageMargins;
 
@@ -288,6 +291,20 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					JRHtmlExporterParameter.PROPERTY_SIZE_UNIT
 					);
 			
+			Float zoomRatio = (Float)parameters.get(JRHtmlExporterParameter.ZOOM_RATIO);
+			if (zoomRatio != null)
+			{
+				zoom = zoomRatio.floatValue();
+				if (zoom <= 0)
+				{
+					throw new JRException("Invalid zoom ratio : " + zoom);
+				}
+			}
+			else
+			{
+				zoom = DEFAULT_ZOOM;
+			}
+	
 			isIgnorePageMargins = 
 				getBooleanParameter(
 					JRExporterParameter.IGNORE_PAGE_MARGINS,
@@ -447,7 +464,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 								new JRWrappingSvgRenderer(
 									renderer,
 									new Dimension(image.getWidth(), image.getHeight()),
-									JRElement.MODE_OPAQUE == image.getMode() ? image.getBackcolor() : null
+									ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
 									);
 						}
 	
@@ -605,7 +622,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	 */
 	protected void exportPage(JRPrintPage page) throws JRException, IOException
 	{
-		writer.write("<div style=\"position:relative;width:" + jasperPrint.getPageWidth() + sizeUnit + ";height:" + jasperPrint.getPageHeight() + sizeUnit + ";\">\n");
+		writer.write("<div style=\"position:relative;width:" + toSizeUnit(jasperPrint.getPageWidth()) + ";height:" + toSizeUnit(jasperPrint.getPageHeight()) + ";\">\n");
 
 		frameIndexStack = new ArrayList();
 		
@@ -690,7 +707,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		float ratio = line.getWidth() / line.getHeight();
 		if (ratio > 1)
 		{
-			if (line.getDirection() == JRLine.DIRECTION_TOP_DOWN)
+			if (line.getDirectionValue() == LineDirectionEnum.TOP_DOWN)
 			{
 				side = "top";
 			}
@@ -701,7 +718,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		}
 		else
 		{
-			if (line.getDirection() == JRLine.DIRECTION_TOP_DOWN)
+			if (line.getDirectionValue() == LineDirectionEnum.TOP_DOWN)
 			{
 				side = "left";
 			}
@@ -865,8 +882,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		}
 
 		writer.write("font-size: ");
-		writer.write(String.valueOf(attributes.get(TextAttribute.SIZE)));
-		writer.write(sizeUnit);
+		writer.write(toSizeUnit(((Float)attributes.get(TextAttribute.SIZE)).intValue()));
 		writer.write(";");
 
 		/*
@@ -948,7 +964,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		appendId(text);
 
-		if (text.getRunDirection() == JRPrintText.RUN_DIRECTION_RTL)
+		if (text.getRunDirectionValue() == RunDirectionEnum.RTL)
 		{
 			writer.write(" dir=\"rtl\"");
 		}
@@ -963,24 +979,24 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		if (textLength > 0)
 		{
-			switch (text.getHorizontalAlignment())
+			switch (text.getHorizontalAlignmentValue())
 			{
-				case JRAlignment.HORIZONTAL_ALIGN_RIGHT :
+				case RIGHT :
 				{
 					horizontalAlignment = CSS_TEXT_ALIGN_RIGHT;
 					break;
 				}
-				case JRAlignment.HORIZONTAL_ALIGN_CENTER :
+				case CENTER :
 				{
 					horizontalAlignment = CSS_TEXT_ALIGN_CENTER;
 					break;
 				}
-				case JRAlignment.HORIZONTAL_ALIGN_JUSTIFIED :
+				case JUSTIFIED :
 				{
 					horizontalAlignment = CSS_TEXT_ALIGN_JUSTIFY;
 					break;
 				}
-				case JRAlignment.HORIZONTAL_ALIGN_LEFT :
+				case LEFT :
 				default :
 				{
 					horizontalAlignment = CSS_TEXT_ALIGN_LEFT;
@@ -1001,19 +1017,19 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 			String verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
 
-			switch (text.getVerticalAlignment())
+			switch (text.getVerticalAlignmentValue())
 			{
-				case JRAlignment.VERTICAL_ALIGN_BOTTOM :
+				case BOTTOM :
 				{
 					verticalAlignment = HTML_VERTICAL_ALIGN_BOTTOM;
 					break;
 				}
-				case JRAlignment.VERTICAL_ALIGN_MIDDLE :
+				case MIDDLE :
 				{
 					verticalAlignment = HTML_VERTICAL_ALIGN_MIDDLE;
 					break;
 				}
-				case JRAlignment.VERTICAL_ALIGN_TOP :
+				case TOP :
 				default :
 				{
 					verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
@@ -1030,11 +1046,11 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		if (isWrapBreakWord)
 		{
-			styleBuffer.append("width: " + text.getWidth() + sizeUnit + "; ");
+			styleBuffer.append("width: " + toSizeUnit(text.getWidth()) + "; ");
 			styleBuffer.append("word-wrap: break-word; ");
 		}
 		
-		if (text.getLineSpacing() != JRTextElement.LINE_SPACING_SINGLE)
+		if (text.getLineSpacingValue() != LineSpacingEnum.SINGLE)
 		{
 			styleBuffer.append("line-height: " + text.getLineSpacingFactor() + "; ");
 		}
@@ -1063,10 +1079,10 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			String textTooltip = hyperlinkStarted ? null : text.getHyperlinkTooltip();
 			exportStyledText(styledText, textTooltip, getTextLocale(text));
 		}
-		else
-		{
-			//writer.write(emptyCellStringProvider.getStringForEmptyTD(imagesURI));
-		}
+//		else
+//		{
+//			//writer.write(emptyCellStringProvider.getStringForEmptyTD(imagesURI));
+//		}
 
 		endHyperlink();
 
@@ -1114,24 +1130,24 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		JRHyperlinkTargetProducer producer = targetProducerFactory.getHyperlinkTargetProducer(link.getLinkTarget());		
 		if (producer == null)
 		{
-			switch(link.getHyperlinkTarget())
+			switch(link.getHyperlinkTargetValue())
 			{
-				case JRHyperlink.HYPERLINK_TARGET_BLANK :
+				case BLANK :
 				{
 					target = "_blank";
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TARGET_PARENT :
+				case PARENT :
 				{
 					target = "_parent";
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TARGET_TOP :
+				case TOP :
 				{
 					target = "_top";
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TARGET_CUSTOM :
+				case CUSTOM :
 				{
 					boolean paramFound = false;
 					List parameters = link.getHyperlinkParameters() == null ? null : link.getHyperlinkParameters().getParameters();
@@ -1154,7 +1170,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TARGET_SELF :
+				case SELF :
 				default :
 				{
 				}
@@ -1175,9 +1191,9 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		JRHyperlinkProducer customHandler = getCustomHandler(link);		
 		if (customHandler == null)
 		{
-			switch(link.getHyperlinkType())
+			switch(link.getHyperlinkTypeValue())
 			{
-				case JRHyperlink.HYPERLINK_TYPE_REFERENCE :
+				case REFERENCE :
 				{
 					if (link.getHyperlinkReference() != null)
 					{
@@ -1185,7 +1201,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_LOCAL_ANCHOR :
+				case LOCAL_ANCHOR :
 				{
 					if (link.getHyperlinkAnchor() != null)
 					{
@@ -1193,7 +1209,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_LOCAL_PAGE :
+				case LOCAL_PAGE :
 				{
 					if (link.getHyperlinkPage() != null)
 					{
@@ -1201,7 +1217,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR :
+				case REMOTE_ANCHOR :
 				{
 					if (
 						link.getHyperlinkReference() != null &&
@@ -1212,7 +1228,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE :
+				case REMOTE_PAGE :
 				{
 					if (
 						link.getHyperlinkReference() != null &&
@@ -1223,7 +1239,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					}
 					break;
 				}
-				case JRHyperlink.HYPERLINK_TYPE_NONE :
+				case NONE :
 				default :
 				{
 					break;
@@ -1331,13 +1347,11 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		}
 		
 		styleBuffer.append("width:");
-		styleBuffer.append(element.getWidth() - widthDiff);
-		styleBuffer.append(sizeUnit);
+		styleBuffer.append(toSizeUnit(element.getWidth() - widthDiff));
 		styleBuffer.append(";");
 
 		styleBuffer.append("height:");
-		styleBuffer.append(element.getHeight() - heightDiff);
-		styleBuffer.append(sizeUnit);
+		styleBuffer.append(toSizeUnit(element.getHeight() - heightDiff));
 		styleBuffer.append(";");
 	}
 
@@ -1352,13 +1366,11 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		}
 		
 		styleBuffer.append("width:");
-		styleBuffer.append(element.getWidth() - diff);
-		styleBuffer.append(sizeUnit);
+		styleBuffer.append(toSizeUnit(element.getWidth() - diff));
 		styleBuffer.append(";");
 
 		styleBuffer.append("height:");
-		styleBuffer.append(element.getHeight() - diff);
-		styleBuffer.append(sizeUnit);
+		styleBuffer.append(toSizeUnit(element.getHeight() - diff));
 		styleBuffer.append(";");
 	}
 
@@ -1367,19 +1379,17 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	{
 		styleBuffer.append("position:absolute;");
 		styleBuffer.append("left:");
-		styleBuffer.append(element.getX());
-		styleBuffer.append(sizeUnit);
+		styleBuffer.append(toSizeUnit(element.getX()));
 		styleBuffer.append(";");
 		styleBuffer.append("top:");
-		styleBuffer.append(element.getY());
-		styleBuffer.append(sizeUnit);
+		styleBuffer.append(toSizeUnit(element.getY()));
 		styleBuffer.append(";");
 	}
 
 
 	protected void appendBackcolorStyle(JRPrintElement element, StringBuffer styleBuffer)
 	{
-		if (element.getMode() == JRElement.MODE_OPAQUE)
+		if (element.getModeValue() == ModeEnum.OPAQUE)
 		{
 			styleBuffer.append("background-color: #");
 			styleBuffer.append(JRColorUtil.getColorHexa(element.getBackcolor()));
@@ -1399,19 +1409,19 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		float xAlignFactor = 0f;
 
-		switch (image.getHorizontalAlignment())
+		switch (image.getHorizontalAlignmentValue())
 		{
-			case JRAlignment.HORIZONTAL_ALIGN_RIGHT :
+			case RIGHT :
 			{
 				xAlignFactor = 1f;
 				break;
 			}
-			case JRAlignment.HORIZONTAL_ALIGN_CENTER :
+			case CENTER :
 			{
 				xAlignFactor = 0.5f;
 				break;
 			}
-			case JRAlignment.HORIZONTAL_ALIGN_LEFT :
+			case LEFT :
 			default :
 			{
 				xAlignFactor = 0f;
@@ -1420,19 +1430,19 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		float yAlignFactor = 0f;
 
-		switch (image.getVerticalAlignment())
+		switch (image.getVerticalAlignmentValue())
 		{
-			case JRAlignment.VERTICAL_ALIGN_BOTTOM :
+			case BOTTOM :
 			{
 				yAlignFactor = 1f;
 				break;
 			}
-			case JRAlignment.VERTICAL_ALIGN_MIDDLE :
+			case MIDDLE :
 			{
 				yAlignFactor = 0.5f;
 				break;
 			}
-			case JRAlignment.VERTICAL_ALIGN_TOP :
+			case TOP :
 			default :
 			{
 				yAlignFactor = 0f;
@@ -1495,7 +1505,8 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			String imageMapName = null;
 			List imageMapAreas = null;
 	
-			byte scaleImage = image.getScaleImage();
+			ScaleImageEnum scaleImage = image.getScaleImageValue();
+			
 			if (renderer != null)
 			{
 				if (renderer.getType() == JRRenderable.TYPE_IMAGE && rendererToImagePathMap.containsKey(renderer.getId()))
@@ -1544,7 +1555,9 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	
 			writer.write(" src=\"");
 			if (imagePath != null)
+			{
 				writer.write(imagePath);
+			}
 			writer.write("\"");
 		
 			int availableImageWidth = image.getWidth() - image.getLineBox().getLeftPadding().intValue() - image.getLineBox().getRightPadding().intValue();
@@ -1561,7 +1574,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		
 			switch (scaleImage)
 			{
-				case JRImage.SCALE_IMAGE_FILL_FRAME :
+				case FILL_FRAME :
 				{
 					int leftDiff = 0;
 					int topDiff = 0;
@@ -1582,22 +1595,18 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					}
 					
 					writer.write(" style=\"position:absolute;left:");
-					writer.write(String.valueOf(leftDiff));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit(leftDiff));
 					writer.write(";top:");
-					writer.write(String.valueOf(topDiff));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit(topDiff));
 					writer.write(";width:");
-					writer.write(String.valueOf(availableImageWidth - widthDiff));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit(availableImageWidth - widthDiff));
 					writer.write(";height:");
-					writer.write(String.valueOf(availableImageHeight - heightDiff));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit(availableImageHeight - heightDiff));
 					writer.write("\"");
 		
 					break;
 				}
-				case JRImage.SCALE_IMAGE_CLIP :
+				case CLIP :
 				{
 					double normalWidth = availableImageWidth;
 					double normalHeight = availableImageHeight;
@@ -1606,7 +1615,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					{
 						// Image load might fail. 
 						JRRenderable tmpRenderer = 
-							JRImageRenderer.getOnErrorRendererForDimension(renderer, image.getOnErrorType());
+							JRImageRenderer.getOnErrorRendererForDimension(renderer, image.getOnErrorTypeValue());
 						Dimension2D dimension = tmpRenderer == null ? null : tmpRenderer.getDimension();
 						// If renderer was replaced, ignore image dimension.
 						if (tmpRenderer == renderer && dimension != null)
@@ -1635,34 +1644,26 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					}
 					
 					writer.write(" style=\"position:absolute;left:");
-					writer.write(String.valueOf(leftDiff + xAlignFactor * (availableImageWidth - widthDiff - normalWidth)));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit((int)(leftDiff + xAlignFactor * (availableImageWidth - widthDiff - normalWidth))));
 					writer.write(";top:");
-					writer.write(String.valueOf(topDiff + yAlignFactor * (availableImageHeight - heightDiff - normalHeight)));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit((int)(topDiff + yAlignFactor * (availableImageHeight - heightDiff - normalHeight))));
 					writer.write(";width:");
-					writer.write(String.valueOf(normalWidth));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit((int)normalWidth));
 					writer.write(";height:");
-					writer.write(String.valueOf(normalHeight));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit((int)normalHeight));
 					writer.write(";clip:rect(");
-					writer.write(String.valueOf(yAlignFactor * (normalHeight - availableImageHeight + heightDiff)));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit((int)(yAlignFactor * (normalHeight - availableImageHeight + heightDiff))));
 					writer.write(",");
-					writer.write(String.valueOf(xAlignFactor * normalWidth + (1 - xAlignFactor) * (availableImageWidth - widthDiff)));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit((int)(xAlignFactor * normalWidth + (1 - xAlignFactor) * (availableImageWidth - widthDiff))));
 					writer.write(",");
-					writer.write(String.valueOf(yAlignFactor * normalHeight + (1 - yAlignFactor) * (availableImageHeight - heightDiff)));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit((int)(yAlignFactor * normalHeight + (1 - yAlignFactor) * (availableImageHeight - heightDiff))));
 					writer.write(",");
-					writer.write(String.valueOf(xAlignFactor * (normalWidth - availableImageWidth + widthDiff)));
-					writer.write(sizeUnit);
+					writer.write(toSizeUnit((int)(xAlignFactor * (normalWidth - availableImageWidth + widthDiff))));
 					writer.write(")\"");
 
 					break;
 				}
-				case JRImage.SCALE_IMAGE_RETAIN_SHAPE :
+				case RETAIN_SHAPE :
 				default :
 				{
 					double normalWidth = availableImageWidth;
@@ -1672,7 +1673,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 					{
 						// Image load might fail. 
 						JRRenderable tmpRenderer = 
-							JRImageRenderer.getOnErrorRendererForDimension(renderer, image.getOnErrorType());
+							JRImageRenderer.getOnErrorRendererForDimension(renderer, image.getOnErrorTypeValue());
 						Dimension2D dimension = tmpRenderer == null ? null : tmpRenderer.getDimension();
 						// If renderer was replaced, ignore image dimension.
 						if (tmpRenderer == renderer && dimension != null)
@@ -1707,28 +1708,22 @@ public class JRXhtmlExporter extends JRAbstractExporter
 						if( ratio > (double)availableImageWidth / (double)availableImageHeight )
 						{
 							writer.write(" style=\"position:absolute;left:");
-							writer.write(String.valueOf(leftDiff));
-							writer.write(sizeUnit);
+							writer.write(toSizeUnit(leftDiff));
 							writer.write(";top:");
-							writer.write(String.valueOf(topDiff + yAlignFactor * (availableImageHeight - heightDiff - (availableImageWidth - widthDiff) / ratio)));
-							writer.write(sizeUnit);
+							writer.write(toSizeUnit((int)(topDiff + yAlignFactor * (availableImageHeight - heightDiff - (availableImageWidth - widthDiff) / ratio))));
 							writer.write(";width:");
-							writer.write(String.valueOf(availableImageWidth - widthDiff));
-							writer.write(sizeUnit);
+							writer.write(toSizeUnit(availableImageWidth - widthDiff));
 							writer.write("\"");
 						}
 						else
 						{
 							writer.write(" style=\"position:absolute;left:");
 							//writer.write(String.valueOf(leftDiff));
-							writer.write(String.valueOf(leftDiff + xAlignFactor * (availableImageWidth - widthDiff - ratio * (availableImageHeight - heightDiff))));
-							writer.write(sizeUnit);
+							writer.write(toSizeUnit((int)(leftDiff + xAlignFactor * (availableImageWidth - widthDiff - ratio * (availableImageHeight - heightDiff)))));
 							writer.write(";top:");
-							writer.write(String.valueOf(topDiff));
-							writer.write(sizeUnit);
+							writer.write(toSizeUnit(topDiff));
 							writer.write(";height:");
-							writer.write(String.valueOf(availableImageHeight - heightDiff));
-							writer.write(sizeUnit);
+							writer.write(toSizeUnit(availableImageHeight - heightDiff));
 							writer.write("\"");
 						}
 					}
@@ -1775,7 +1770,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		{
 			Integer frameIndex = (Integer)frameIndexStack.get(i);
 
-			sbuffer.append(frameIndex + "_");
+			sbuffer.append(frameIndex).append("_");
 		}
 		
 		JRPrintElementIndex imageIndex =
@@ -1803,7 +1798,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 			writer.write("/>\n");
 		}
 		
-		if (image.getHyperlinkType() != JRHyperlink.HYPERLINK_TYPE_NONE)
+		if (image.getHyperlinkTypeValue() != HyperlinkTypeEnum.NONE)
 		{
 			writer.write("  <area shape=\"default\"");
 			writeImageAreaCoordinates(new int[]{0, 0, image.getWidth(), image.getHeight()});//for IE
@@ -1876,8 +1871,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 				sb.append(side);
 			}
 			sb.append(": ");
-			sb.append(padding);
-			sb.append(sizeUnit);
+			sb.append(toSizeUnit(padding.intValue()));
 			sb.append("; ");
 
 			addedToStyle = true;
@@ -1901,24 +1895,24 @@ public class JRXhtmlExporter extends JRAbstractExporter
 		}
 
 		String borderStyle = null;
-		switch (pen.getLineStyle().byteValue())
+		switch (pen.getLineStyleValue())
 		{
-			case JRPen.LINE_STYLE_DOUBLE :
+			case DOUBLE :
 			{
 				borderStyle = "double";
 				break;
 			}
-			case JRPen.LINE_STYLE_DOTTED :
+			case DOTTED :
 			{
 				borderStyle = "dotted";
 				break;
 			}
-			case JRPen.LINE_STYLE_DASHED :
+			case DASHED :
 			{
 				borderStyle = "dashed";
 				break;
 			}
-			case JRPen.LINE_STYLE_SOLID :
+			case SOLID :
 			default :
 			{
 				borderStyle = "solid";
@@ -1945,8 +1939,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 				sb.append(side);
 			}
 			sb.append("-width: ");
-			sb.append((int)borderWidth);
-			sb.append(sizeUnit);
+			sb.append(toSizeUnit((int)borderWidth));
 			sb.append("; ");
 
 			sb.append("border");
@@ -2023,7 +2016,7 @@ public class JRXhtmlExporter extends JRAbstractExporter
 
 		writer.write(">\n");
 		
-		frameIndexStack.add(new Integer(elementIndex));
+		frameIndexStack.add(Integer.valueOf(elementIndex));
 
 		exportElements(frame.getElements());
 
@@ -2092,6 +2085,12 @@ public class JRXhtmlExporter extends JRAbstractExporter
 	}
 
 
+	public String toSizeUnit(int size)
+	{
+		return String.valueOf((int)(zoom * size)) + sizeUnit;
+	}
+
+
 	protected JRStyledText getStyledText(JRPrintText textElement,
 			boolean setBackcolor)
 	{
