@@ -59,6 +59,10 @@ import net.sf.jasperreports.engine.query.JRQueryExecuter;
 import net.sf.jasperreports.engine.query.JRQueryExecuterFactory;
 import net.sf.jasperreports.engine.scriptlets.ScriptletFactory;
 import net.sf.jasperreports.engine.scriptlets.ScriptletFactoryContext;
+import net.sf.jasperreports.engine.type.CalculationEnum;
+import net.sf.jasperreports.engine.type.IncrementTypeEnum;
+import net.sf.jasperreports.engine.type.ResetTypeEnum;
+import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
 import net.sf.jasperreports.engine.util.JRQueryExecuterUtils;
 import net.sf.jasperreports.engine.util.JRResourcesUtil;
 import net.sf.jasperreports.extensions.ExtensionsEnvironment;
@@ -68,7 +72,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillDataset.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillDataset.java 3675 2010-04-02 08:58:23Z shertage $
  */
 public class JRFillDataset implements JRDataset
 {
@@ -157,7 +161,7 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The resource missing handle type.
 	 */
-	protected byte whenResourceMissingType;
+	protected WhenResourceMissingTypeEnum whenResourceMissingType;
 	
 	/**
 	 * The scriptlet class name.
@@ -228,7 +232,7 @@ public class JRFillDataset implements JRDataset
 		
 		scriptletClassName = dataset.getScriptletClass();
 		resourceBundleBaseName = dataset.getResourceBundle();
-		whenResourceMissingType = dataset.getWhenResourceMissingType();
+		whenResourceMissingType = dataset.getWhenResourceMissingTypeValue();
 		
 		query = dataset.getQuery();
 		
@@ -294,31 +298,31 @@ public class JRFillDataset implements JRDataset
 	{
 		JRFillVariable variable = factory.getVariable(parentVariable);
 
-		byte calculation = variable.getCalculation();
+		CalculationEnum calculation = variable.getCalculationValue();
 		switch (calculation)
 		{
-			case JRVariable.CALCULATION_AVERAGE:
-			case JRVariable.CALCULATION_VARIANCE:
+			case AVERAGE:
+			case VARIANCE:
 			{
-				JRVariable countVar = createHelperVariable(parentVariable, "_COUNT", JRVariable.CALCULATION_COUNT);
+				JRVariable countVar = createHelperVariable(parentVariable, "_COUNT", CalculationEnum.COUNT);
 				JRFillVariable fillCountVar = addVariable(countVar, variableList, factory);
 				variable.setHelperVariable(fillCountVar, JRCalculable.HELPER_COUNT);
 
-				JRVariable sumVar = createHelperVariable(parentVariable, "_SUM", JRVariable.CALCULATION_SUM);
+				JRVariable sumVar = createHelperVariable(parentVariable, "_SUM", CalculationEnum.SUM);
 				JRFillVariable fillSumVar = addVariable(sumVar, variableList, factory);
 				variable.setHelperVariable(fillSumVar, JRCalculable.HELPER_SUM);
 
 				break;
 			}
-			case JRVariable.CALCULATION_STANDARD_DEVIATION:
+			case STANDARD_DEVIATION:
 			{
-				JRVariable varianceVar = createHelperVariable(parentVariable, "_VARIANCE", JRVariable.CALCULATION_VARIANCE);
+				JRVariable varianceVar = createHelperVariable(parentVariable, "_VARIANCE", CalculationEnum.VARIANCE);
 				JRFillVariable fillVarianceVar = addVariable(varianceVar, variableList, factory);
 				variable.setHelperVariable(fillVarianceVar, JRCalculable.HELPER_VARIANCE);
 
 				break;
 			}
-			case JRVariable.CALCULATION_DISTINCT_COUNT:
+			case DISTINCT_COUNT:
 			{
 				JRVariable countVar = createDistinctCountHelperVariable(parentVariable);
 				JRFillVariable fillCountVar = addVariable(countVar, variableList, factory);
@@ -332,15 +336,15 @@ public class JRFillDataset implements JRDataset
 		return variable;
 	}
 
-	private JRVariable createHelperVariable(JRVariable variable, String nameSuffix, byte calculation)
+	private JRVariable createHelperVariable(JRVariable variable, String nameSuffix, CalculationEnum calculation)
 	{
 		JRDesignVariable helper = new JRDesignVariable();
 		helper.setName(variable.getName() + nameSuffix);
 		helper.setValueClassName(variable.getValueClassName());
 		helper.setIncrementerFactoryClassName(variable.getIncrementerFactoryClassName());
-		helper.setResetType(variable.getResetType());
+		helper.setResetType(variable.getResetTypeValue());
 		helper.setResetGroup(variable.getResetGroup());
-		helper.setIncrementType(variable.getIncrementType());
+		helper.setIncrementType(variable.getIncrementTypeValue());
 		helper.setIncrementGroup(variable.getIncrementGroup());
 		helper.setCalculation(calculation);
 		helper.setSystemDefined(true);
@@ -355,13 +359,14 @@ public class JRFillDataset implements JRDataset
 		helper.setName(variable.getName() + "_DISTINCT_COUNT");
 		helper.setValueClassName(variable.getValueClassName());
 		helper.setIncrementerFactoryClassName(JRDistinctCountIncrementerFactory.class.getName());
-		helper.setResetType(JRVariable.RESET_TYPE_REPORT);
+		helper.setResetType(ResetTypeEnum.REPORT);
 
-		if (variable.getIncrementType() != JRVariable.RESET_TYPE_NONE)
-			helper.setResetType(variable.getIncrementType());
-			
+		if (variable.getIncrementTypeValue() != IncrementTypeEnum.NONE)
+		{
+			helper.setResetType(ResetTypeEnum.getByValue(variable.getIncrementTypeValue().getValue()));
+		}
 		helper.setResetGroup(variable.getIncrementGroup());
-		helper.setCalculation(JRVariable.CALCULATION_NOTHING);
+		helper.setCalculation(CalculationEnum.NOTHING);
 		helper.setSystemDefined(true);
 		helper.setExpression(variable.getExpression());
 		
@@ -450,7 +455,7 @@ public class JRFillDataset implements JRDataset
 	 */
 	protected List createScriptlets(Map parameterValues) throws JRException
 	{
-		ScriptletFactoryContext context = new ScriptletFactoryContext(parameterValues);
+		ScriptletFactoryContext context = new ScriptletFactoryContext(parameterValues, this);
 		
 		scriptlets = new ArrayList();
 		
@@ -994,9 +999,9 @@ public class JRFillDataset implements JRDataset
 	{
 		String variableName;
 
-		byte calculation;
+		CalculationEnum calculation;
 
-		VariableCalculationReq(String variableName, byte calculation)
+		VariableCalculationReq(String variableName, CalculationEnum calculation)
 		{
 			this.variableName = variableName;
 			this.calculation = calculation;
@@ -1016,7 +1021,7 @@ public class JRFillDataset implements JRDataset
 
 		public int hashCode()
 		{
-			return 31 * calculation + variableName.hashCode();
+			return 31 * calculation.getValue() + variableName.hashCode();
 		}
 	}
 	
@@ -1027,7 +1032,7 @@ public class JRFillDataset implements JRDataset
 	 * @param variableName the variable name
 	 * @param calculation the required calculation
 	 */
-	protected void addVariableCalculationReq(String variableName, byte calculation)
+	protected void addVariableCalculationReq(String variableName, CalculationEnum calculation)
 	{
 		if (variableCalculationReqs == null)
 		{
@@ -1062,11 +1067,11 @@ public class JRFillDataset implements JRDataset
 	
 	private void checkVariableCalculationReq(JRFillVariable variable, List variableList, JRFillObjectFactory factory)
 	{
-		if (hasVariableCalculationReq(variable, JRVariable.CALCULATION_AVERAGE) || hasVariableCalculationReq(variable, JRVariable.CALCULATION_VARIANCE))
+		if (hasVariableCalculationReq(variable, CalculationEnum.AVERAGE) || hasVariableCalculationReq(variable, CalculationEnum.VARIANCE))
 		{
 			if (variable.getHelperVariable(JRCalculable.HELPER_COUNT) == null)
 			{
-				JRVariable countVar = createHelperVariable(variable, "_COUNT", JRVariable.CALCULATION_COUNT);
+				JRVariable countVar = createHelperVariable(variable, "_COUNT", CalculationEnum.COUNT);
 				JRFillVariable fillCountVar = factory.getVariable(countVar);
 				checkVariableCalculationReq(fillCountVar, variableList, factory);
 				variable.setHelperVariable(fillCountVar, JRCalculable.HELPER_COUNT);
@@ -1074,25 +1079,25 @@ public class JRFillDataset implements JRDataset
 
 			if (variable.getHelperVariable(JRCalculable.HELPER_SUM) == null)
 			{
-				JRVariable sumVar = createHelperVariable(variable, "_SUM", JRVariable.CALCULATION_SUM);
+				JRVariable sumVar = createHelperVariable(variable, "_SUM", CalculationEnum.SUM);
 				JRFillVariable fillSumVar = factory.getVariable(sumVar);
 				checkVariableCalculationReq(fillSumVar, variableList, factory);
 				variable.setHelperVariable(fillSumVar, JRCalculable.HELPER_SUM);
 			}
 		}
 
-		if (hasVariableCalculationReq(variable, JRVariable.CALCULATION_STANDARD_DEVIATION))
+		if (hasVariableCalculationReq(variable, CalculationEnum.STANDARD_DEVIATION))
 		{
 			if (variable.getHelperVariable(JRCalculable.HELPER_VARIANCE) == null)
 			{
-				JRVariable varianceVar = createHelperVariable(variable, "_VARIANCE", JRVariable.CALCULATION_VARIANCE);
+				JRVariable varianceVar = createHelperVariable(variable, "_VARIANCE", CalculationEnum.VARIANCE);
 				JRFillVariable fillVarianceVar = factory.getVariable(varianceVar);
 				checkVariableCalculationReq(fillVarianceVar, variableList, factory);
 				variable.setHelperVariable(fillVarianceVar, JRCalculable.HELPER_VARIANCE);
 			}
 		}
 
-		if (hasVariableCalculationReq(variable, JRVariable.CALCULATION_DISTINCT_COUNT))
+		if (hasVariableCalculationReq(variable, CalculationEnum.DISTINCT_COUNT))
 		{
 			if (variable.getHelperVariable(JRCalculable.HELPER_COUNT) == null)
 			{
@@ -1107,7 +1112,7 @@ public class JRFillDataset implements JRDataset
 	}
 
 	
-	private boolean hasVariableCalculationReq(JRVariable var, byte calculation)
+	private boolean hasVariableCalculationReq(JRVariable var, CalculationEnum calculation)
 	{
 		return variableCalculationReqs.contains(new VariableCalculationReq(var.getName(), calculation));
 	}
@@ -1174,13 +1179,31 @@ public class JRFillDataset implements JRDataset
 	}
 
 
+	/**
+	 * @deprecated Replaced by {@link #getWhenResourceMissingType()}.
+	 */
 	public byte getWhenResourceMissingType()
+	{
+		return getWhenResourceMissingTypeValue().getValue();
+	}
+
+
+	public WhenResourceMissingTypeEnum getWhenResourceMissingTypeValue()
 	{
 		return whenResourceMissingType;
 	}
 
 
+	/**
+	 * @deprecated Replaced by {@link #setWhenResourceMissingType(WhenResourceMissingTypeEnum)}.
+	 */
 	public void setWhenResourceMissingType(byte whenResourceMissingType)
+	{
+		setWhenResourceMissingType(WhenResourceMissingTypeEnum.getByValue(whenResourceMissingType));
+	}
+
+	
+	public void setWhenResourceMissingType(WhenResourceMissingTypeEnum whenResourceMissingType)
 	{
 		this.whenResourceMissingType = whenResourceMissingType;
 	}
@@ -1200,7 +1223,8 @@ public class JRFillDataset implements JRDataset
 	
 	public JRPropertiesHolder getParentProperties()
 	{
-		return null;
+		// report properties propagate to subdatasets
+		return isMain ? null : filler.getJasperReport();
 	}
 
 
