@@ -49,15 +49,19 @@ import net.sf.jasperreports.engine.JRPropertiesMap;
 import net.sf.jasperreports.engine.JRPropertyExpression;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRStyleSetter;
-import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JasperPrint;
+import net.sf.jasperreports.engine.type.CalculationEnum;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.PositionTypeEnum;
+import net.sf.jasperreports.engine.type.StretchTypeEnum;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillElement.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillElement.java 3673 2010-04-01 13:14:19Z shertage $
  */
 public abstract class JRFillElement implements JRElement, JRFillCloneable, JRStyleSetter
 {
@@ -217,33 +221,67 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getPositionTypeValue()}.
 	 */
 	public byte getPositionType()
 	{
-		return parent.getPositionType();//FIXME optimize this by consolidating style properties
+		return getPositionTypeValue().getValue();
 	}
 
 	/**
 	 *
 	 */
+	public PositionTypeEnum getPositionTypeValue()
+	{
+		return parent.getPositionTypeValue();//FIXME optimize this by consolidating style properties
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setPositionType(PositionTypeEnum)}.
+	 */
 	public void setPositionType(byte positionType)
 	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
 	 *
 	 */
+	public void setPositionType(PositionTypeEnum positionType)
+	{
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getStretchTypeValue()}.
+	 */
 	public byte getStretchType()
 	{
 		return parent.getStretchType();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setStretchType(StretchTypeEnum)}.
 	 */
 	public void setStretchType(byte stretchType)
 	{
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 *
+	 */
+	public StretchTypeEnum getStretchTypeValue()
+	{
+		return parent.getStretchTypeValue();
+	}
+
+	/**
+	 *
+	 */
+	public void setStretchType(StretchTypeEnum stretchType)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
@@ -262,35 +300,58 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getModeValue()}.
 	 */
 	public byte getMode()
 	{
-		return JRStyleResolver.getMode(this, MODE_OPAQUE);
+		return getModeValue().getValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getOwnModeValue()}.
+	 */
+	public Byte getOwnMode()
+	{
+		return getOwnModeValue() == null ? null : getOwnModeValue().getValueByte();
 	}
 
 	/**
 	 *
 	 */
-	public Byte getOwnMode()
+	public ModeEnum getModeValue()
 	{
-		return parent.getOwnMode();
+		return JRStyleResolver.getMode(this, ModeEnum.OPAQUE);
 	}
 
 	/**
 	 *
 	 */
+	public ModeEnum getOwnModeValue()
+	{
+		return parent.getOwnModeValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
+	 */
 	public void setMode(byte mode)
 	{
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
 	 */
 	public void setMode(Byte mode)
 	{
 	}
 
+	/**
+	 *
+	 */
+	public void setMode(ModeEnum modeValue)
+	{
+	}
+
 	/**
 	 *
 	 */
@@ -710,7 +771,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	protected JRTemplateElement getElementTemplate()
 	{
 		JRStyle style = getStyle();
-		JRTemplateElement template = (JRTemplateElement) getTemplate(style);
+		JRTemplateElement template = getTemplate(style);
 		if (template == null)
 		{
 			template = createElementTemplate();
@@ -756,14 +817,14 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	 */
 	protected void stretchElement(int bandStretch)
 	{
-		switch (getStretchType())
+		switch (getStretchTypeValue())
 		{
-			case JRElement.STRETCH_TYPE_RELATIVE_TO_BAND_HEIGHT :
+			case RELATIVE_TO_BAND_HEIGHT :
 			{
 				setStretchHeight(getHeight() + bandStretch);
 				break;
 			}
-			case JRElement.STRETCH_TYPE_RELATIVE_TO_TALLEST_OBJECT :
+			case RELATIVE_TO_TALLEST_OBJECT :
 			{
 				if (elementGroup != null)
 				{
@@ -773,7 +834,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 
 				break;
 			}
-			case JRElement.STRETCH_TYPE_NO_STRETCH :
+			case NO_STRETCH :
 			default :
 			{
 				break;
@@ -911,9 +972,9 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	}
 	
 	// default for elements not supporting evaluationTime
-	protected byte getEvaluationTime()
+	protected EvaluationTimeEnum getEvaluationTimeValue()
 	{
-		return JRExpression.EVALUATION_TIME_NOW;
+		return EvaluationTimeEnum.NOW;
 	}
 
 	/**
@@ -925,12 +986,12 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	 */
 	protected void resolveElement (JRPrintElement element, byte evaluation, JREvaluationTime evaluationTime) throws JRException
 	{
-		byte evaluationTimeType = getEvaluationTime();
+		EvaluationTimeEnum evaluationTimeType = getEvaluationTimeValue();
 		switch (evaluationTimeType)
 		{
-			case JRExpression.EVALUATION_TIME_NOW:
+			case NOW:
 				break;
-			case JRExpression.EVALUATION_TIME_AUTO:
+			case AUTO:
 				delayedEvaluate((JRRecordedValuesPrintElement) element, evaluationTime, evaluation);
 				break;
 			default:
@@ -955,7 +1016,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 
 	protected void initDelayedEvaluations()
 	{
-		if (getEvaluationTime() == JRExpression.EVALUATION_TIME_AUTO && delayedEvaluationsMap == null)
+		if (getEvaluationTimeValue() == EvaluationTimeEnum.AUTO && delayedEvaluationsMap == null)
 		{
 			delayedEvaluationsMap = new HashMap();
 			collectDelayedEvaluations();
@@ -1054,18 +1115,18 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	{
 		JRFillVariable variable = getVariable(variableName);
 		JREvaluationTime evaluationTime;
-		switch (variable.getResetType())
+		switch (variable.getResetTypeValue())
 		{
-			case JRVariable.RESET_TYPE_REPORT:
+			case REPORT:
 				evaluationTime = JREvaluationTime.EVALUATION_TIME_REPORT;
 				break;
-			case JRVariable.RESET_TYPE_PAGE:
+			case PAGE:
 				evaluationTime = JREvaluationTime.EVALUATION_TIME_PAGE;
 				break;
-			case JRVariable.RESET_TYPE_COLUMN:
+			case COLUMN:
 				evaluationTime = JREvaluationTime.EVALUATION_TIME_COLUMN;
 				break;
-			case JRVariable.RESET_TYPE_GROUP:
+			case GROUP:
 				evaluationTime = JREvaluationTime.getGroupEvaluationTime(variable.getResetGroup().getName());
 				break;
 			default:
@@ -1079,7 +1140,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 			evaluationTime = JREvaluationTime.EVALUATION_TIME_NOW;
 		}
 		
-		if (variable.getCalculation() == JRVariable.CALCULATION_SYSTEM &&
+		if (variable.getCalculationValue() == CalculationEnum.SYSTEM &&
 				evaluationTime.equals(JREvaluationTime.EVALUATION_TIME_NOW) &&
 				band.isVariableUsedInSubreportReturns(variableName))
 		{
@@ -1231,10 +1292,13 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 		JRStyle evalStyle = crtStyle;
 
 		if (conditionalStylesContainer != null)
+		{
 			evalStyle = conditionalStylesContainer.getEvaluatedConditionalStyle(crtStyle);
-		
+		}
 		if (isUsingDefaultStyle && evalStyle == crtStyle)
+		{
 			evalStyle = null;
+		}
 		
 		return evalStyle;
 	}
@@ -1282,13 +1346,13 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	protected boolean isEvaluateNow()
 	{
 		boolean evaluateNow;
-		switch (getEvaluationTime())
+		switch (getEvaluationTimeValue())
 		{
-			case JRExpression.EVALUATION_TIME_NOW:
+			case NOW:
 				evaluateNow = true;
 				break;
 
-			case JRExpression.EVALUATION_TIME_AUTO:
+			case AUTO:
 				evaluateNow = isAutoEvaluateNow();
 				break;
 
@@ -1310,7 +1374,7 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	
 	protected boolean isEvaluateAuto()
 	{
-		return getEvaluationTime() == JRExpression.EVALUATION_TIME_AUTO && !isAutoEvaluateNow();
+		return getEvaluationTimeValue() == EvaluationTimeEnum.AUTO && !isAutoEvaluateNow();
 	}
 
 	public String getStyleNameReference()
