@@ -30,7 +30,6 @@ import java.io.File;
 import java.io.InputStream;
 import java.net.URL;
 
-import net.sf.jasperreports.engine.JRAlignment;
 import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
@@ -45,13 +44,20 @@ import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRRenderable;
 import net.sf.jasperreports.engine.JRVisitor;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.OnErrorTypeEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillImage.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillImage.java 3833 2010-05-27 14:16:59Z teodord $
  */
 public class JRFillImage extends JRFillGraphicElement implements JRImage
 {
@@ -109,90 +115,168 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getScaleImageValue()}.
+	 */
+	public byte getScaleImage()
+	{
+		return getScaleImageValue().getValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
+	 */
+	public Byte getOwnScaleImage()
+	{
+		return getOwnScaleImageValue() == null ? null : getOwnScaleImageValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
+	 */
+	public void setScaleImage(byte scaleImage)
+	{
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
+	 */
+	public void setScaleImage(Byte scaleImage)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
 	 * 
 	 */
-	public byte getScaleImage()
+	public ScaleImageEnum getScaleImageValue()
 	{
-		return JRStyleResolver.getScaleImage(this);
+		return JRStyleResolver.getScaleImageValue(this);
 	}
 		
-	public Byte getOwnScaleImage()
+	public ScaleImageEnum getOwnScaleImageValue()
 	{
-		return ((JRImage)this.parent).getOwnScaleImage();
+		return ((JRImage)this.parent).getOwnScaleImageValue();
 	}
 
 	/**
 	 *
 	 */
-	public void setScaleImage(byte scaleImage)
+	public void setScaleImage(ScaleImageEnum scaleImage)
 	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
-	 *
-	 */
-	public void setScaleImage(Byte scaleImage)
-	{
-	}
-
-	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignmentValue().getValue();
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
+	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return ((JRImage)this.parent).getOwnHorizontalAlignment();
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return JRStyleResolver.getHorizontalAlignmentValue(this);
+	}
+		
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return ((JRImage)this.parent).getOwnHorizontalAlignmentValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
 	 *
 	 */
-	public byte getVerticalAlignment()
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignment)
 	{
-		return JRStyleResolver.getVerticalAlignment(this);
+		throw new UnsupportedOperationException();
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
+	public byte getVerticalAlignment()
+	{
+		return getVerticalAlignmentValue().getValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
+	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return ((JRImage)this.parent).getOwnVerticalAlignment();
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
 	}
 
 	/**
 	 *
 	 */
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return JRStyleResolver.getVerticalAlignmentValue(this);
+	}
+		
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return ((JRImage)this.parent).getOwnVerticalAlignmentValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
+	public void setVerticalAlignment(Byte verticalAlignment)
+	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
 	 *
 	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
@@ -241,26 +325,51 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOnErrorTypeValue()}.
 	 */
 	public byte getOnErrorType()
 	{
-		return ((JRImage)this.parent).getOnErrorType();
+		return getOnErrorTypeValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setOnErrorType(OnErrorTypeEnum)}.
 	 */
 	public void setOnErrorType(byte onErrorType)
 	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
 	 *
 	 */
+	public OnErrorTypeEnum getOnErrorTypeValue()
+	{
+		return ((JRImage)this.parent).getOnErrorTypeValue();
+	}
+		
+	/**
+	 *
+	 */
+	public void setOnErrorType(OnErrorTypeEnum onErrorType)
+	{
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getEvaluationTimeValue()}.
+	 */
 	public byte getEvaluationTime()
 	{
-		return ((JRImage)this.parent).getEvaluationTime();
+		return getEvaluationTimeValue().getValue();
+	}
+		
+	/**
+	 *
+	 */
+	public EvaluationTimeEnum getEvaluationTimeValue()
+	{
+		return ((JRImage)this.parent).getEvaluationTimeValue();
 	}
 		
 	/**
@@ -728,11 +837,19 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
 	 */
 	public byte getHyperlinkType()
 	{
-		return ((JRImage)this.parent).getHyperlinkType();
+		return getHyperlinkTypeValue().getValue();
+	}
+
+	/**
+	 *
+	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return ((JRImage)parent).getHyperlinkTypeValue();
 	}
 		
 	/**
@@ -856,10 +973,10 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 				this
 				);
 		
-		if (getScaleImage() == JRImage.SCALE_IMAGE_REAL_HEIGHT
-				|| getScaleImage() == JRImage.SCALE_IMAGE_REAL_SIZE)
+		if (getScaleImageValue() == ScaleImageEnum.REAL_HEIGHT
+				|| getScaleImageValue() == ScaleImageEnum.REAL_SIZE)
 		{
-			template.setScaleImage(JRImage.SCALE_IMAGE_RETAIN_SHAPE);
+			template.setScaleImage(ScaleImageEnum.RETAIN_SHAPE);
 		}
 		
 		return template;
@@ -875,20 +992,16 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	{
 		initDelayedEvaluations();
 		
-		this.reset();
+		reset();
 		
-		this.evaluatePrintWhenExpression(evaluation);
+		evaluatePrintWhenExpression(evaluation);
 
-		if (
-			(this.isPrintWhenExpressionNull() ||
-			(!this.isPrintWhenExpressionNull() && 
-			this.isPrintWhenTrue()))
-			)
+		if (isPrintWhenExpressionNull() || isPrintWhenTrue())
 		{
 			if (isEvaluateNow())
 			{
 				hasOverflowed = false;
-				this.evaluateImage(evaluation);
+				evaluateImage(evaluation);
 			}
 		}
 	}
@@ -921,22 +1034,22 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 				if (Image.class.getName().equals(expressionClass.getName()))
 				{
 					Image img = (Image) source;
-					newRenderer = JRImageRenderer.getInstance(img, getOnErrorType());
+					newRenderer = JRImageRenderer.getInstance(img, getOnErrorTypeValue());
 				}
 				else if (InputStream.class.getName().equals(expressionClass.getName()))
 				{
 					InputStream is = (InputStream) source;
-					newRenderer = JRImageRenderer.getInstance(is, getOnErrorType());
+					newRenderer = JRImageRenderer.getInstance(is, getOnErrorTypeValue());
 				}
 				else if (URL.class.getName().equals(expressionClass.getName()))
 				{
 					URL url = (URL) source;
-					newRenderer = JRImageRenderer.getInstance(url, getOnErrorType());
+					newRenderer = JRImageRenderer.getInstance(url, getOnErrorTypeValue());
 				}
 				else if (File.class.getName().equals(expressionClass.getName()))
 				{
 					File file = (File) source;
-					newRenderer = JRImageRenderer.getInstance(file, getOnErrorType());
+					newRenderer = JRImageRenderer.getInstance(file, getOnErrorTypeValue());
 				}
 				else if (String.class.getName().equals(expressionClass.getName()))
 				{
@@ -944,7 +1057,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 					newRenderer = 
 						JRImageRenderer.getInstance(
 							location, 
-							getOnErrorType(), 
+							getOnErrorTypeValue(), 
 							isLazy(), 
 							filler.reportClassLoader,
 							filler.urlHandlerFactory,
@@ -1046,8 +1159,8 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 					isToPrint = false;
 					willOverflow = true;
 				}
-				else if (!isLazy() && (getScaleImage() == JRImage.SCALE_IMAGE_REAL_HEIGHT
-						|| getScaleImage() == JRImage.SCALE_IMAGE_REAL_SIZE))
+				else if (!isLazy() && (getScaleImageValue() == ScaleImageEnum.REAL_HEIGHT
+						|| getScaleImageValue() == ScaleImageEnum.REAL_SIZE))
 				{
 					int padding = getLineBox().getBottomPadding().intValue() 
 							+ getLineBox().getTopPadding().intValue();
@@ -1058,7 +1171,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 					boolean imageOverflowAllowed = 
 							filler.isBandOverFlowAllowed() && !reprinted && !hasOverflowed;
 					boolean fits = fitImage(availableHeight - getRelativeY() - padding, imageOverflowAllowed, 
-							getHorizontalAlignment());
+							getHorizontalAlignmentValue());
 					if (fits)
 					{
 						if (imageHeight != null)
@@ -1129,7 +1242,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 
 	protected boolean fitImage(int availableHeight, boolean overflowAllowed,
-			byte hAlign) throws JRException
+			HorizontalAlignEnum hAlign) throws JRException
 	{
 		imageHeight = null;
 		imageWidth = null;
@@ -1156,10 +1269,10 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		
 		if (reducedHeight <= availableHeight)
 		{
-			imageHeight = new Integer(reducedHeight);
-			if (getScaleImage() == JRImage.SCALE_IMAGE_REAL_SIZE)
+			imageHeight = Integer.valueOf(reducedHeight);
+			if (getScaleImageValue() == ScaleImageEnum.REAL_SIZE)
 			{
-				imageWidth = new Integer(reducedWidth);
+				imageWidth = Integer.valueOf(reducedWidth);
 			}
 			fitted = true;
 		}
@@ -1169,11 +1282,11 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		}
 		else
 		{
-			imageHeight = new Integer(availableHeight);
-			if (getScaleImage() == JRImage.SCALE_IMAGE_REAL_SIZE)
+			imageHeight = Integer.valueOf(availableHeight);
+			if (getScaleImageValue() == ScaleImageEnum.REAL_SIZE)
 			{
 				double hRatio = ((double) availableHeight) / realHeight;
-				imageWidth = new Integer((int) (hRatio * realWidth));
+				imageWidth = Integer.valueOf((int) (hRatio * realWidth));
 			}
 			fitted = true;
 		}
@@ -1182,11 +1295,11 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		{
 			switch (hAlign)
 			{
-			case JRAlignment.HORIZONTAL_ALIGN_RIGHT:
-				imageX = new Integer(getX() + getWidth() - imageWidth.intValue());
+			case RIGHT:
+				imageX = Integer.valueOf(getX() + getWidth() - imageWidth.intValue());
 				break;
-			case JRAlignment.HORIZONTAL_ALIGN_CENTER:
-				imageX = new Integer(getX() + (getWidth() - imageWidth.intValue()) / 2);
+			case CENTER:
+				imageX = Integer.valueOf(getX() + (getWidth() - imageWidth.intValue()) / 2);
 				break;
 			default:
 				break;
@@ -1201,7 +1314,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	 */
 	protected JRPrintElement fill() throws JRException
 	{
-		byte evaluationType = this.getEvaluationTime();
+		EvaluationTimeEnum evaluationTime = this.getEvaluationTimeValue();
 		JRTemplatePrintImage printImage;
 		JRRecordedValuesPrintImage recordedValuesImage;
 		if (isEvaluateAuto())
@@ -1229,7 +1342,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		}
 		else
 		{
-			filler.addBoundElement(this, printImage, evaluationType, getEvaluationGroup(), band);
+			filler.addBoundElement(this, printImage, evaluationTime, getEvaluationGroup(), band);
 		}
 		
 		return printImage;
@@ -1287,7 +1400,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		int padding = printImage.getLineBox().getBottomPadding().intValue() 
 				+ printImage.getLineBox().getTopPadding().intValue();
 		fitImage(getHeight() - padding, false, 
-				printImage.getHorizontalAlignment());
+				printImage.getHorizontalAlignmentValue());
 		
 		copy(printImage);
 	}
