@@ -55,7 +55,7 @@ import org.apache.commons.logging.LogFactory;
  * Default text measurer implementation.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: TextMeasurer.java 3202 2009-11-19 13:08:37Z teodord $
+ * @version $Id: TextMeasurer.java 3746 2010-04-16 17:05:18Z lucianc $
  */
 public class TextMeasurer implements JRTextMeasurer
 {
@@ -177,7 +177,7 @@ public class TextMeasurer implements JRTextMeasurer
 				}
 
 				int breakOffset = textOffset - lastOffset;
-				lineBreakOffsets.add(new Integer(breakOffset));
+				lineBreakOffsets.add(Integer.valueOf(breakOffset));
 				lastOffset = textOffset;
 			}
 		}
@@ -264,9 +264,9 @@ public class TextMeasurer implements JRTextMeasurer
 		bottomPadding = textElement.getLineBox().getBottomPadding().intValue();
 		rightPadding = textElement.getLineBox().getRightPadding().intValue();
 
-		switch (textElement.getRotation())
+		switch (textElement.getRotationValue())
 		{
-			case JRTextElement.ROTATION_LEFT :
+			case LEFT :
 			{
 				width = textElement.getHeight();
 				height = textElement.getWidth();
@@ -277,7 +277,7 @@ public class TextMeasurer implements JRTextMeasurer
 				rightPadding = tmpPadding;
 				break;
 			}
-			case JRTextElement.ROTATION_RIGHT :
+			case RIGHT :
 			{
 				width = textElement.getHeight();
 				height = textElement.getWidth();
@@ -288,7 +288,7 @@ public class TextMeasurer implements JRTextMeasurer
 				leftPadding = tmpPadding;
 				break;
 			}
-			case JRTextElement.ROTATION_UPSIDE_DOWN :
+			case UPSIDE_DOWN :
 			{
 				int tmpPadding = topPadding;
 				topPadding = bottomPadding;
@@ -298,26 +298,26 @@ public class TextMeasurer implements JRTextMeasurer
 				rightPadding = tmpPadding;
 				break;
 			}
-			case JRTextElement.ROTATION_NONE :
+			case NONE :
 			default :
 			{
 			}
 		}
 		
 		/*   */
-		switch (textElement.getLineSpacing())
+		switch (textElement.getLineSpacingValue())
 		{
-			case JRTextElement.LINE_SPACING_SINGLE : 
+			case SINGLE : 
 			{
 				lineSpacing = 1f;
 				break;
 			}
-			case JRTextElement.LINE_SPACING_1_1_2 : 
+			case ONE_AND_HALF : 
 			{
 				lineSpacing = 1.5f;
 				break;
 			}
-			case JRTextElement.LINE_SPACING_DOUBLE : 
+			case DOUBLE : 
 			{
 				lineSpacing = 2f;
 				break;
@@ -596,10 +596,10 @@ public class TextMeasurer implements JRTextMeasurer
 		if (truncateSuffx != null)
 		{
 			truncateSuffx = truncateSuffx.trim();
-		}
-		if (truncateSuffx.length() == 0)
-		{
-			truncateSuffx = null;
+			if (truncateSuffx.length() == 0)
+			{
+				truncateSuffx = null;
+			}
 		}
 		return truncateSuffx;
 	}
@@ -676,7 +676,7 @@ public class TextMeasurer implements JRTextMeasurer
 							attributes.getIndex() + stringOffset,
 							attributes.getRunLimit(attribute) + stringOffset);
 				}
-			};
+			}
 		}
 	}
 	
